# Euklid [2D and 3D vector operations]

[![PyPI version](https://badge.fury.io/py/euklid.svg)](https://badge.fury.io/py/euklid)

A c++ library with bindings for python to help dealing with common CAD-like operations:

 * [Vectors](./src/vector/README.md)
 * [PolyLines](./src/polyline/README.md)
 * [Spline Curves](./src/spline/README.md)


## Installation


### install via pip:

`pip install euklid`

### Compile from source:

``` bash
git clone https://github.com/airgproducts/euklid
cd euklid
git submodule init
git submodule update
pip install .
```
